#import <WebKit/WebView.h>
#import <WebKit/WebFrame.h>
#import "WebViewWindow.h"

@implementation WebViewWindow
- (id)initWithContentRect:(NSRect)contentRect 
                styleMask:(unsigned int)aStyle 
                  backing:(NSBackingStoreType)bufferingType 
                    defer:(BOOL)flag 
{
   //Call NSWindow's version of this function, but pass in the all-important value of NSBorderlessWindowMask
   //for the styleMask so that the window doesn't have a title bar
   if (self = [super initWithContentRect:contentRect 
								styleMask:NSBorderlessWindowMask 
								backing:bufferingType 
								defer:flag]) 
	{        
      [self setLevel: NSModalPanelWindowLevel];
      //[self setLevel: NSStatusWindowLevel];
      //Set the background color to clear so that (along with the setOpaque call below) we can see through the parts
      //of the window that we're not drawing into
      [self setBackgroundColor: [NSColor clearColor]];
      //This next line pulls the window up to the front on top of other system windows.  This is how the Clock app behaves;
      //generally you wouldn't do this for windows unless you really wanted them to float above everything.
      [self setLevel: NSStatusWindowLevel];
      //Let's start with no transparency for all drawing into the window
      [self setAlphaValue:1.0];
      //but let's turn off opaqueness so that we can see through the parts of the window that we're not drawing into
      [self setOpaque:NO];
      //and while we're at it, make sure the window has a shadow, which will automatically be the shape of our custom content.
      [self setHasShadow: NO];
   }    
   return self;
}

- (void)awakeFromNib
{
   [thisWebView setDrawsBackground:NO];
   [self setView: thisWebView with: @"Flash" ofType:@"swf" onWindow:self]; 
   //[self setView: thisWebView with: @"FlashPage" ofType:@"html" onWindow:self]; 
   //[self setOpaque:NO];
   //[self setHasShadow: NO];
}

- (void)setView:(WebView*)view with:(NSString*) str ofType:(NSString*) type onWindow: (NSWindow*) window
{
   NSString *path;
   // Locate the resource inside the applications bundle.
   path = [[NSBundle mainBundle] pathForResource: str ofType: type];
   
   NSString *protocol = @"file://";
   NSString *urlString = [protocol stringByAppendingString:path];

                                
   // Set the WebView delegates
   [view setFrameLoadDelegate:window];
   [view setUIDelegate:window];
   [view setResourceLoadDelegate:window];
   
   NSURL *url = [NSURL URLWithString:urlString];
   NSURLRequest *urlReq = [NSURLRequest requestWithURL:url];
   
   WebFrame* webFrame = [view mainFrame];
   [webFrame loadRequest: urlReq];
   
}
@end
